@@ -79,12 +79,21 @@ class Dictionary:
 			assert isinstance(value, str)
 			yield "/".join(str(stroke) for stroke in key), value
 
+	def items_str_dict(self)->Dict[str, str]:
+		"""
+		Get the dictionary as a dict from str (RTF/CRE) to str.
+		"""
+		result_items=list(self.items_str())
+		result=dict(result_items)
+		assert len(result_items)==len(result)
+		return result
+
 	def print_items(self)->None:
 		"""
 		Print all items in the dictionary in JSON format.
 		"""
 		import json
-		json.dump(dict(self.items_str()), sys.stdout, ensure_ascii=False, indent=0)
+		json.dump(self.items_str_dict(), sys.stdout, ensure_ascii=False, indent=0)
 
 	def __or__(self, other: "Dictionary")->"Dictionary":
 		"""
@@ -108,9 +117,6 @@ class Dictionary:
 		"""
 		Map a function over the dictionary values.
 		"""
-		argspec=inspect.getfullargspec(function)
-		assert not argspec.varargs
-
 		return MappedDictionary(self.stroke_type, self, function)
 
 	def filter(self, condition: Callable[[Strokes, Any], Any])->"Dictionary":
@@ -223,8 +229,12 @@ def apply_function(function: Callable, strokes: Strokes, result: Any)->Any:
 	f(**kwargs): Same as above. kwargs["strokes"] will be available.
 	
 	"""
-	argspec=inspect.getfullargspec(function)
-	include_strokes=argspec.varkw is not None or "strokes" in argspec.args
+	include_strokes: bool=False
+	try:
+		argspec=inspect.getfullargspec(function)
+		include_strokes=argspec.varkw is not None or "strokes" in argspec.args
+	except TypeError:  # for built-in functions like str
+		pass
 
 	assert result is not None
 	if isinstance(result, CompoundResult):
